@@ -1,5 +1,5 @@
 // VoRS -- Vo(IP) Really Simple
-// Copyright (C) 2024 Sergey Matveev <stargrave@stargrave.org>
+// Copyright (C) 2024-2025 Sergey Matveev <stargrave@stargrave.org>
 //
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU Affero General Public License as
@@ -19,7 +19,7 @@ import (
 	"log"
 
 	"go.stargrave.org/opus/v2"
-	vors "go.stargrave.org/vors/internal"
+	vors "go.stargrave.org/vors/v6/internal"
 )
 
 func newOpusEnc() *opus.Encoder {
@@ -43,7 +43,7 @@ func newOpusEnc() *opus.Encoder {
 }
 
 func pcmConv(buf []byte, pcm []int16) {
-	for i := 0; i < len(pcm); i++ {
+	for i := range len(pcm) {
 		buf[i*2+0] = byte((uint16(pcm[i]) & 0x00FF) >> 0)
 		buf[i*2+1] = byte((uint16(pcm[i]) & 0xFF00) >> 8)
 	}
