@@ -1,14 +1,14 @@
 package main
 
 import (
+	"crypto/cipher"
 	"hash"
 	"log/slog"
 	"net"
 	"sync"
 	"time"
 
-	"github.com/flynn/noise"
-	vors "go.stargrave.org/vors/internal"
+	vors "go.stargrave.org/vors/v6/internal"
 )
 
 var (
@@ -17,29 +17,33 @@ var (
 )
 
 type Stats struct {
+	last    time.Time
 	pktsRx  int64
 	pktsTx  int64
+	bads    int64
 	bytesRx uint64
 	bytesTx uint64
-	bads    int64
-	last    time.Time
 }
 
 type Peer struct {
 	name  string
-	sid   byte
 	addr  *net.UDPAddr
-	key   []byte
-	mac   hash.Hash
 	stats *Stats
 	room  *Room
+	key   []byte
+	mac   hash.Hash
+	muted bool
+	sid   byte
 
-	logger     *slog.Logger
-	conn       net.Conn
-	rx, tx     chan []byte
-	rxCS, txCS *noise.CipherState
-	alive      chan struct{}
-	aliveOnce  sync.Once
+	logger    *slog.Logger
+	conn      *vors.NSConn
+	rxAEAD    cipher.AEAD
+	txAEAD    cipher.AEAD
+	rxNonce   []byte
+	txNonce   []byte
+	rx, tx    chan []byte
+	alive     chan struct{}
+	aliveOnce sync.Once
 }
 
 func (peer *Peer) Close() {
@@ -47,42 +51,33 @@ func (peer *Peer) Close() {
 		close(peer.rx)
 		close(peer.tx)
 		close(peer.alive)
-		peer.conn.Close()
+		peer.conn.Conn.Close()
 	})
 }
 
 func (peer *Peer) Rx() {
-	for {
-		buf, err := vors.PktRead(peer.conn)
-		if err != nil {
-			peer.logger.Error("rx", "err", err)
-			break
-		}
-		buf, err = peer.rxCS.Decrypt(buf[:0], nil, buf)
+	var err error
+	for buf := range peer.conn.Rx {
+		buf, err = peer.rxAEAD.Open(buf[:0], peer.rxNonce, buf, nil)
 		if err != nil {
 			peer.logger.Error("rx decrypt", "err", err)
 			break
 		}
 		peer.rx <- buf
+		vors.Incr(peer.rxNonce)
 	}
 	peer.Close()
 }
 
 func (peer *Peer) Tx() {
+	var err error
 	for buf := range peer.tx {
-		if peer.txCS == nil {
-			continue
-		}
-		buf, err := peer.txCS.Encrypt(buf[:0], nil, buf)
-		if err != nil {
-			peer.logger.Error("tx encrypt", "err", err)
-			break
-		}
-		err = vors.PktWrite(peer.conn, buf)
-		if err != nil {
-			peer.logger.Error("tx", "err", err)
+		buf = peer.txAEAD.Seal(nil, peer.txNonce, buf, nil)
+		if err = peer.conn.Tx(buf); err != nil {
+			peer.logger.Error("tx write", "err", err)
 			break
 		}
+		vors.Incr(peer.txNonce)
 	}
 	peer.Close()
 }
