@@ -7,9 +7,10 @@ import (
 )
 
 var (
-	CGreen string
-	CRed   string
-	CReset string
+	CGreen   string
+	CRed     string
+	CMagenta string
+	CReset   string
 )
 
 func init() {
@@ -17,5 +18,6 @@ func init() {
 	t := term.NewTerminal(&b, "")
 	CGreen = string(t.Escape.Green)
 	CRed = string(t.Escape.Red)
+	CMagenta = string(t.Escape.Magenta)
 	CReset = string(t.Escape.Reset)
 }
